@@ -1,10 +1,11 @@
 package Var::Pairs;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.002004';
 
 use 5.014;
 use warnings;
 no if $] >= 5.018, warnings => "experimental::smartmatch";
+no if $] >= 5.020, warnings => "experimental::autoderef";
 use Carp;
 use Devel::Callsite;
 
@@ -116,7 +117,7 @@ sub pairs (+) {
     }
 
     # Uniquely identify this call, according to its lexical context...
-    my $ID = callsite();
+    my $ID = callsite() . $container_ref;
 
     # Short-circuit if this is a repeated call...
     if (!wantarray && $iterator_for{$ID}) {
@@ -140,7 +141,7 @@ sub each_pair (+) {
     my ($container_ref) = @_;
 
     # Uniquely identify this call, according to its lexical context...
-    my $ID = callsite();
+    my $ID = callsite() . $container_ref;
 
     # Build an iterator...
     $iterator_for{$ID} //= [ &pairs ];
@@ -167,7 +168,7 @@ sub kvs (+) {
     }
 
     # Uniquely identify this call, according to its lexical context...
-    my $ID = callsite();
+    my $ID = callsite() . $container_ref;
 
     # Return the key/value list, according to the container type...
     if ($container_type eq 'ARRAY') {
@@ -181,8 +182,8 @@ sub kvs (+) {
 sub each_kv (+) {
     my ($container_ref) = @_;
 
-    # Uniquely identify this call, according to its lexical context...
-    my $ID = callsite();
+    # Uniquely identify this call, according to its lexical context and iteration target...
+    my $ID = callsite() . $container_ref;
 
     # Build an iterator...
     $iterator_for{$ID} //= [ &kvs ];
@@ -364,7 +365,7 @@ Var::Pairs - OO iterators and pair constructors for variables
 
 =head1 VERSION
 
-This document describes Var::Pairs version 0.002000
+This document describes Var::Pairs version 0.002004
 
 
 =head1 SYNOPSIS
@@ -378,9 +379,9 @@ This document describes Var::Pairs version 0.002000
     }
 
 
-    # next_pair() iterates OO pairs from arrays and hashes...
+    # each_pair() iterates OO pairs from arrays and hashes...
 
-    while (my $next = next_pair %hash) {
+    while (my $next = each_pair %hash) {
         say $next->key, ' had the value ', $next->value;
         $next->value++;
     }
@@ -533,9 +534,11 @@ The typical scalar usage is:
     }
 
 In other words, C<each_kv()> is a drop-in replacement for Perl's
-built-in C<each()>, except that you can nest C<each_kv()>
-iterations over the same variable without shooting yourself in
-the foot.
+built-in C<each()>, with two exceptions: one an advantage, the other a
+limitation. The advantage is that you can nest C<each_kv()> iterations
+over the same variable without shooting yourself in the foot. The
+limitation is that, unlike C<each()>, C<each_kv()> does not reset
+when you call the C<keys> function on the hash you're iterating.
 
 =back
 
@@ -868,6 +871,12 @@ Please report any bugs or feature requests to
 C<bug-var-pairs@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
+C<each_kv()> acts like a true one-time only iterator (in the OO sense),
+so there is no way to reset its iteration (i.e. the way that calling
+C<keys()> on a hash or array, resets any C<each()> that is iterating
+it). If you need to reset partially iterated hashes or arrays, you will
+need to use some other mechanism to do so.
+
 
 =head1 ACKNOWLEDGEMENTS
 
